about summary refs log tree commit diff
path: root/youtube_dl/extractor/common.py
diff options
context:
space:
mode:
authorSergey M․ <dstftw@gmail.com>2021-04-06 14:22:28 +0700
committerSergey M․ <dstftw@gmail.com>2021-04-06 14:22:28 +0700
commit70d0d4f9beba0e5b6d95ee50ad62ae7ab5be9be1 (patch)
treec8f2a5a8971dcb2b2ce14cc7eadcc30785c71c73 /youtube_dl/extractor/common.py
parent6b315d96bc0b07ddc3abaa7318583775828cce30 (diff)
downloadyoutube-dl-70d0d4f9beba0e5b6d95ee50ad62ae7ab5be9be1.tar.gz
youtube-dl-70d0d4f9beba0e5b6d95ee50ad62ae7ab5be9be1.tar.xz
youtube-dl-70d0d4f9beba0e5b6d95ee50ad62ae7ab5be9be1.zip
[compat] Use more conventional name for compat SimpleCookie
Diffstat (limited to 'youtube_dl/extractor/common.py')
-rw-r--r--youtube_dl/extractor/common.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/youtube_dl/extractor/common.py b/youtube_dl/extractor/common.py
index af289d705..797c35fd5 100644
--- a/youtube_dl/extractor/common.py
+++ b/youtube_dl/extractor/common.py
@@ -17,13 +17,13 @@ import math
 
 from ..compat import (
     compat_cookiejar_Cookie,
+    compat_cookies_SimpleCookie,
     compat_etree_Element,
     compat_etree_fromstring,
     compat_getpass,
     compat_integer_types,
     compat_http_client,
     compat_os_name,
-    compat_SimpleCookie,
     compat_str,
     compat_urllib_error,
     compat_urllib_parse_unquote,
@@ -2901,10 +2901,10 @@ class InfoExtractor(object):
         self._downloader.cookiejar.set_cookie(cookie)
 
     def _get_cookies(self, url):
         """ Return a compat_SimpleCookie with the cookies for the url """
         req = sanitized_Request(url)
         self._downloader.cookiejar.add_cookie_header(req)
-        return compat_SimpleCookie(req.get_header('Cookie'))
+        return compat_cookies_SimpleCookie(req.get_header('Cookie'))
 
     def _apply_first_set_cookie_header(self, url_handle, cookie):
         """
@@ -2901,10 +2901,10 @@ class InfoExtractor(object):
 
     def _get_cookies(self, url):
-        """ Return a compat_SimpleCookie with the cookies for the url """
+        """ Return a compat_cookies_SimpleCookie with the cookies for the url """
         req = sanitized_Request(url)
         self._downloader.cookiejar.add_cookie_header(req)